@@ -13,10 +13,12 @@ logger = logging.get_logger(__name__)
 
 class FeedManager:
     feeds: Dict[FeedKey, Feed]
+    accounts: Dict[str, Dict[int, int]]
     _node: "AbstractNode"
 
     def __init__(self, node: "AbstractNode") -> None:
         self.feeds = {}
+        self.accounts = {}
         self._node = node
 
     def __contains__(self, item):
@@ -32,29 +34,54 @@ class FeedManager:
             )
         self.feeds[feed.feed_key] = feed
 
-    def subscribe_to_feed(
-        self, feed_key: FeedKey, options: Dict[str, Any]
-    ) -> Optional[Subscriber]:
+    def subscribe_to_feed(self, feed_key: FeedKey, options: Dict[str, Any]) -> Optional[Subscriber]:
         if feed_key in self.feeds:
             subscriber = self.feeds[feed_key].subscribe(options)
             logger.debug(
-                "Creating new subscriber ({}) to {}", subscriber.subscription_id, feed_key.name
+                "Creating new subscriber ({}) to {}", subscriber.subscription_id, feed_key
             )
             self._node.reevaluate_transaction_streamer_connection()
+            account_id = options.get("account_id", None)
+            if account_id is not None:
+                if account_id in self.accounts:
+                    open_feeds = self.accounts.get(account_id)
+                    assert open_feeds is not None
+                    if feed_key.network_num in open_feeds:
+                        open_feeds[feed_key.network_num] += 1
+                    else:
+                        open_feeds[feed_key.network_num] = 1
+                else:
+                    self.accounts[account_id] = {feed_key.network_num: 1}
             return subscriber
         else:
             return None
 
     def unsubscribe_from_feed(
-        self, feed_key: FeedKey, subscriber_id: str
+        self,
+        feed_key: FeedKey,
+        subscriber_id: str,
+        account_id: Optional[str] = None
     ) -> Optional[Subscriber]:
         subscriber = self.feeds[feed_key].unsubscribe(subscriber_id)
         if subscriber is not None:
             logger.debug(
                 "Unsubscribing subscriber ({}) from {}",
                 subscriber.subscription_id,
-                feed_key.name,
+                feed_key,
             )
+
+            # Subtract the feed from the account counting
+            if account_id is not None:
+                if account_id in self.accounts:
+                    open_feeds = self.accounts.get(account_id)
+                    if open_feeds is not None and feed_key.network_num in open_feeds:
+                        if open_feeds[feed_key.network_num] == 1:
+                            open_feeds.pop(feed_key.network_num)
+                            if len(open_feeds) == 0:
+                                self.accounts.pop(account_id)
+                        else:
+                            open_feeds[feed_key.network_num] -= 1
+
         self._node.reevaluate_transaction_streamer_connection()
         return subscriber
 
@@ -79,3 +106,6 @@ class FeedManager:
 
     def validate_feed_filters(self, feed_key: FeedKey, filters: str) -> Tuple[str, List[str]]:
         return self.feeds[feed_key].validate_filters(filters)
+
+    def open_feeds_count(self, account_id: str) -> Optional[Dict[int, int]]:
+        return self.accounts.get(account_id, {})
