@@ -1,12 +1,15 @@
 from bxcommon.messages.bloxroute.bloxroute_message_type import BloxrouteMessageType
+from bxcommon.messages.bloxroute.v13.pong_message_converter_v13 import pong_message_converter_v13
+from bxcommon.messages.bloxroute.v14.message_converter_factory_v14 import message_converter_factory_v14
 from bxcommon.messages.versioning.abstract_version_converter_factory import AbstractMessageConverterFactory
 from bxcommon.messages.versioning.no_changes_message_converter import no_changes_message_converter
-from bxcommon.messages.bloxroute.v13.pong_message_converter_v13 import pong_message_converter_v13
 
 
 class _MessageConverterFactoryV13(AbstractMessageConverterFactory):
     _MESSAGE_CONVERTER_MAPPING = {
-        BloxrouteMessageType.PONG: pong_message_converter_v13
+        # pylint: disable=protected-access
+        **message_converter_factory_v14._MESSAGE_CONVERTER_MAPPING,
+        BloxrouteMessageType.PONG: pong_message_converter_v13,
     }
 
     def get_message_converter(self, msg_type):
