@@ -1,8 +1,6 @@
 from bxcommon.messages.bloxroute.bloxroute_message_type import BloxrouteMessageType
-from bxcommon.messages.bloxroute.v13.pong_message_converter_v13 import pong_message_converter_v13
 from bxcommon.messages.bloxroute.v8.broadcast_message_converter_v8 import broadcast_message_converter_v8
-from bxcommon.messages.bloxroute.v9.bdn_performance_stats_message_converter_v9 \
-    import bdn_performance_stats_message_converter_v9
+from bxcommon.messages.bloxroute.v9.message_converter_factory_v9 import message_converter_factory_v9
 from bxcommon.messages.versioning.abstract_version_converter_factory import AbstractMessageConverterFactory
 from bxcommon.messages.versioning.no_changes_message_converter import no_changes_message_converter
 from bxcommon.messages.versioning.abstract_message_converter import AbstractMessageConverter
@@ -10,9 +8,9 @@ from bxcommon.messages.versioning.abstract_message_converter import AbstractMess
 
 class _MessageConverterFactoryV8(AbstractMessageConverterFactory):
     _MESSAGE_CONVERTER_MAPPING = {
-        BloxrouteMessageType.BDN_PERFORMANCE_STATS: bdn_performance_stats_message_converter_v9,
+        # pylint: disable=protected-access
+        **message_converter_factory_v9._MESSAGE_CONVERTER_MAPPING,
         BloxrouteMessageType.BROADCAST: broadcast_message_converter_v8,
-        BloxrouteMessageType.PONG: pong_message_converter_v13
     }
 
     def get_message_converter(self, msg_type) -> AbstractMessageConverter:
