@@ -9,17 +9,19 @@ class NodeEventType(SerializeableEnum):
     PEER_CONN_CLOSED = "PEER_CONN_CLOSED"
     ONLINE = "ONLINE"
     OFFLINE = "OFFLINE"
-    NOTIFY_ONLINE = "NOTIFY_ONLINE"
     NOTIFY_OFFLINE = "NOTIFY_OFFLINE"
     SID_SPACE_EAGER_FETCH = "SID_SPACE_EAGER_FETCH"
     SID_SPACE_FULL = "SID_SPACE_FULL"
     SID_SPACE_SWITCH = "SID_SPACE_SWITCH"
     BLOCKCHAIN_NODE_CONN_ERR = "BLOCKCHAIN_NODE_CONN_ERR"
     BLOCKCHAIN_NODE_CONN_ESTABLISHED = "BLOCKCHAIN_NODE_CONN_ESTABLISHED"
+    BLOCKCHAIN_NODE_CONN_ADDED = "BLOCKCHAIN_NODE_CONN_ADDED"
+    BLOCKCHAIN_NODE_CONN_REMOVED = "BLOCKCHAIN_NODE_CONN_REMOVED"
     REMOTE_BLOCKCHAIN_CONN_ERR = "REMOTE_BLOCKCHAIN_CONN_ERR"
     REMOTE_BLOCKCHAIN_CONN_ESTABLISHED = "REMOTE_BLOCKCHAIN_CONN_ESTABLISHED"
     TX_SERVICE_FULLY_SYNCED = "TX_SERVICE_FULLY_SYNCED"
     TX_SERVICE_NOT_SYNCED = "TX_SERVICE_NOT_SYNCED"
+    SWITCHING_RELAYS = "SWITCHING_RELAYS"
 
 @dataclass
 class NodeEventModel:
