@@ -1,14 +1,15 @@
 import json
 from typing import Any
 
-from bxcommon.utils.class_json_encoder import ClassJsonEncoder
+from bxutils.encoding.json_encoder import EnhancedJSONEncoder
 
 
 def serialize(obj: Any) -> str:
     """
     Serializes object into a string JSON
+    DEPRECATED use json_encoder.to_json directly
 
     :param obj: object to serialize
     :return: JSON string
     """
-    return json.dumps(obj, cls=ClassJsonEncoder)
+    return json.dumps(obj, cls=EnhancedJSONEncoder)
