@@ -1,5 +1,6 @@
 import time
 import typing
+from abc import ABC
 from typing import TYPE_CHECKING, TypeVar
 
 from bxcommon.connections.abstract_connection import AbstractConnection
@@ -23,7 +24,7 @@ GatewayNode = TypeVar("GatewayNode", bound="AbstractGatewayNode")
 logger = logging.get_logger(__name__)
 
 
-class AbstractGatewayBlockchainConnection(AbstractConnection[GatewayNode]):
+class AbstractGatewayBlockchainConnection(AbstractConnection[GatewayNode], ABC):
     CONNECTION_TYPE = ConnectionType.BLOCKCHAIN_NODE
 
     def __init__(self, sock: AbstractSocketConnectionProtocol, node: GatewayNode):
@@ -69,37 +70,6 @@ class AbstractGatewayBlockchainConnection(AbstractConnection[GatewayNode]):
             return False
         return self.endpoint.ip_address == other.endpoint.ip_address and self.endpoint.port == other.endpoint.port
 
-    def advance_bytes_written_to_socket(self, bytes_sent):
-        if self.message_tracker and self.message_tracker.is_sending_block_message():
-            assert self.node.opts.track_detailed_sent_messages
-
-            entry = self.message_tracker.messages[0]
-            super(AbstractGatewayBlockchainConnection, self).advance_bytes_written_to_socket(bytes_sent)
-
-            if not self.message_tracker.is_sending_block_message():
-                block_message = typing.cast(AbstractBlockMessage, entry.message)
-                block_message_queue_time = entry.queued_time
-                block_message_length = entry.length
-                block_hash = block_message.block_hash()
-                handling_time, relay_desc = self.node.track_block_from_bdn_handling_ended(block_hash)
-                block_stats.add_block_event_by_block_hash(block_hash,
-                                                          BlockStatEventType.BLOCK_SENT_TO_BLOCKCHAIN_NODE,
-                                                          network_num=self.network_num,
-                                                          more_info="{} in {}; Handled in {}; R - {}; {}".format(
-                                                              stats_format.byte_count(
-                                                                  block_message_length
-                                                              ),
-                                                              stats_format.timespan(
-                                                                  block_message_queue_time,
-                                                                  time.time()
-                                                              ),
-                                                              stats_format.duration(handling_time),
-                                                              relay_desc,
-                                                              block_message.extra_stats_data()
-                                                          ))
-        else:
-            super(AbstractGatewayBlockchainConnection, self).advance_bytes_written_to_socket(bytes_sent)
-
     def log_connection_mem_stats(self) -> None:
         """
         logs the connection's memory stats
@@ -132,7 +102,6 @@ class AbstractGatewayBlockchainConnection(AbstractConnection[GatewayNode]):
         return f"Connection state: {self.state}"
 
     def dispose(self):
-        super().dispose()
 
         if self.CONNECTION_TYPE == ConnectionType.BLOCKCHAIN_NODE:
             self.node.on_blockchain_connection_destroyed(self)
@@ -142,3 +111,4 @@ class AbstractGatewayBlockchainConnection(AbstractConnection[GatewayNode]):
             else:
                 logger.warning(log_messages.CLOSE_CONNECTION_ATTEMPT,
                                self.peer_desc, self.node.remote_node_conn.peer_desc)
+        super().dispose()
