@@ -41,3 +41,6 @@ class PingBtcMessage(BtcMessage):
                 self._nonce = struct.unpack_from("<Q", self.buf, BTC_HDR_COMMON_OFF)[0]
 
         return self._nonce
+
+    def log_level(self) -> LogLevel:
+        return LogLevel.DEBUG
