@@ -1,5 +1,4 @@
-import rlp
-
+import blxr_rlp as rlp
 from bxgateway.messages.eth.protocol.eth_protocol_message import EthProtocolMessage
 from bxgateway.messages.eth.protocol.eth_protocol_message_type import EthProtocolMessageType
 
