@@ -5,9 +5,6 @@ ONT_MAGIC_NUMBERS = {
     "polaris": 0x2D8829DF
 }
 
-STARTUP_SYNC_PORT = 20338
-STARTUP_HTTP_INFO_PORT = 20333
-STARTUP_CONS_PORT = 9999
 STARTUP_CAP = bytes(32)
 STARTUP_RELAY_STATE = True
 STARTUP_IS_CONSENSUS = True
