@@ -32,4 +32,4 @@ class BtcBlockQueuingService(
             magic=block_message.magic(),
             inv_vects=[(InventoryType.MSG_BLOCK, block_hash)],
         )
-        self.node.send_msg_to_node(inv_msg)
+        self.connection.enqueue_msg(inv_msg)
\ No newline at end of file
